<?php

use Automattic\WooCommerce\Blocks\Payments\Integrations\AbstractPaymentMethodType;

final class WC_Gateway_Nomod_Blocks_Support extends AbstractPaymentMethodType
{
	private $gateway;
	protected $name = 'nomod';

	public function initialize()
	{
		$this->settings = get_option('woocommerce_nomod_settings', []);
		$gateways       = WC()->payment_gateways->payment_gateways();
		$this->gateway  = $gateways[$this->name];
	}

	public function is_active()
	{
		return $this->gateway->is_available();
	}

	public function get_payment_method_script_handles()
	{
		$script_path       = '/assets/js/frontend/blocks.js';
		$script_asset_path = WC_Nomod::plugin_abspath() . 'assets/js/frontend/blocks.asset.php';
		$script_asset      = file_exists($script_asset_path)
			? require($script_asset_path)
			: array(
				'dependencies' => array(),
				'version'      => '1.2.0'
			);
		$script_url        = WC_Nomod::plugin_url() . $script_path;

		wp_register_script(
			'wc-nomod-blocks-support',
			$script_url,
			$script_asset['dependencies'],
			$script_asset['version'],
			true
		);

		if (function_exists('wp_set_script_translations')) {
			wp_set_script_translations('wc-nomod-blocks-support', 'nomod-for-woocommerce', WC_Nomod::plugin_abspath() . 'languages/');
		}

		return ['wc-nomod-blocks-support'];
	}

	public function get_payment_method_data()
	{
		$settings = get_option('woocommerce_nomod_settings');
		$title = isset($settings['title']) ? $settings['title'] : __('Visa, Mastercard, American Express, Apple Pay, Google Pay, Tabby, & Tamara', 'nomod-for-woocommerce');
		return [
			'title'       => $title,
			'supports'    => array_filter($this->gateway->supports, [$this->gateway, 'supports'])
		];
	}
}
