<?php
if (! defined('ABSPATH')) {
    exit;
}

class WC_Nomod_Checkout
{
    public static function generate_checkout_link($order_id, $customer_id)
    {
        $order = wc_get_order($order_id);

        $order->calculate_totals();
        $order->save();

        $supported_currencies =  WC_Nomod_Currencies::get_supported_currencies();
        $currency = WC_Nomod_Utils::find_currency_by_code($supported_currencies, $order->get_currency());

        if (null === $currency) {
            throw new Exception(esc_html(WC_Nomod_Messages::get_message('unsupported_currency')));
        }

        $order_id = $order->get_id();
        $order_key = $order->get_order_key();

        list($order_items, $order_taxes, $order_discount) = WC_Nomod_Utils::prepare_order_items($order);

        if (!$order_id || !$order_key || empty($order_items)) {
            throw new Exception(esc_html(WC_Nomod_Messages::get_message('something_wrong')));
        }

        $success_url = WC_Nomod_Utils::get_success_url($order);
        $failure_url = WC_Nomod_Utils::get_failure_url();

        $payload = [
            'currency'              => $currency['code'],
            'amount'                => WC_Nomod_Utils::get_nomod_amount($order->get_total(), false),
            'items'                 => $order_items,
            'taxes'                 => $order_taxes,
            'discount'              => $order_discount,
            'customer'              => $customer_id,
            'success_url'           => $success_url,
            'failure_url'           => $failure_url,
            'woocommerce_order_id'  => $order_id,
            'woocommerce_order_key' => $order_key
        ];

        return WC_Nomod_API::post($payload, 'woocommerce/checkout');
    }

    public static function get_invoice_statuses()
    {
        $response = WC_Nomod_API::get('woocommerce/invoice/statuses');

        if (is_array($response) && isset($response['invoice_statuses']) && is_array($response['invoice_statuses'])) {
            return array_keys($response['invoice_statuses']);
        }

        return [];
    }
}
