<?php
if (! defined('ABSPATH')) {
    exit;
}

class WC_Nomod_Customer
{
    public static function create_customer_if_not_exists($order_id)
    {
        $order = wc_get_order($order_id);
        $customer_email = $order->get_billing_email();

        $payload = [
            'email' => $customer_email,
        ];
        $customer = WC_Nomod_API::post($payload, 'customers/retrieve-by-email');

        if ($customer) {
            return $customer;
        }

        return self::create_customer($order);
    }

    private static function create_customer($order)
    {
        $first_name = $order->get_billing_first_name();
        $last_name = $order->get_billing_last_name();
        $email = $order->get_billing_email();
        $billing_phone = $order->get_billing_phone();
        $billing_zip = $order->get_billing_postcode();
        $billing_address = $order->get_billing_address_1();
        $billing_city = $order->get_billing_city();

        $payload = [
            'first_name' => WC_Nomod_Utils::truncate_string($first_name, 150),
            'last_name' => WC_Nomod_Utils::truncate_string($last_name, 150),
            'email' => $email,
            'street' => $billing_address,
            'city' => $billing_city,
        ];

        if (!empty($billing_phone)) {
            $payload['phone_number'] = $billing_phone;
        }

        if (!empty($billing_zip)) {
            $payload['zip_code'] = $billing_zip;
        }

        return WC_Nomod_API::post($payload, 'customers');
    }
}
