<?php

/**
 * Plugin Name: Nomod for WooCommerce
 * Description: Accept Visa, Mastercard, American Express, Apple Pay, Google Pay, Tabby, & Tamara seamlessly on your WooCommerce store with Nomod.
 * Version: 1.0.3
 * Author: Nomod
 * Author URI: https://nomod.com/
 * Requires Plugins: woocommerce
 * Tested up to: 6.7
 * License: GPLv3 or later
 * License URI: https://www.gnu.org/licenses/gpl-3.0.en.html
 */

if (!defined('ABSPATH')) {
	exit;
}

// Admin notice if WooCommerce is not installed
function nomod_missing_wc_notice()
{
	/* translators: Display missing WooCommerce message */
	echo '<div class="error"><p><strong>' . sprintf(esc_html__('Nomod for WooCommerce requires WooCommerce to be installed and active. You can download %s here.', 'nomod-for-woocommerce'), '<a href="https://woo.com/" target="_blank">WooCommerce</a>') . '</strong></p></div>';
}

register_activation_hook(__FILE__, 'nomod_activate');

// Activation hook to check WooCommerce and settings
function nomod_activate()
{
	if (!class_exists('WooCommerce')) {
		add_action('admin_notices', 'nomod_missing_wc_notice');
		return;
	}
}

class WC_Nomod
{

	public static function init()
	{
		// Register hooks
		add_action('plugins_loaded', array(__CLASS__, 'includes'), 0);
		add_filter('woocommerce_payment_gateways', array(__CLASS__, 'add_gateway'));
		add_action('woocommerce_api_wc_nomod_webhook', array('WC_Nomod_Payment_Webhook', 'handle_nomod_payment_webhook'));
		add_action('template_redirect', array(__CLASS__, 'maybe_display_payment_failed_error'));
		add_action('before_woocommerce_init', array(__CLASS__, 'nomod_for_woocommerce_hcoc_support'));
		add_action('woocommerce_blocks_loaded', array(__CLASS__, 'nomod_for_woocommerce_block_support'));
	}

	public static function add_gateway($gateways)
	{
		$gateways[] = 'WC_Gateway_Nomod'; // Add the Nomod gateway to WooCommerce
		return $gateways;
	}

	public static function includes()
	{
		// Include necessary files
		require_once dirname(__FILE__) . '/includes/class-wc-gateway-nomod.php';
		include_once dirname(__FILE__) . '/includes/class-wc-nomod-api.php';
		require_once dirname(__FILE__) . '/includes/class-wc-nomod-business.php';
		require_once dirname(__FILE__) . '/includes/class-wc-nomod-currencies.php';
		require_once dirname(__FILE__) . '/includes/class-wc-nomod-checkout.php';
		require_once dirname(__FILE__) . '/includes/class-wc-nomod-payment-webhook.php';
		require_once dirname(__FILE__) . '/includes/class-wc-nomod-customer.php';
		require_once dirname(__FILE__) . '/includes/class-wc-nomod-messages.php';
		require_once dirname(__FILE__) . '/includes/class-wc-nomod-utils.php';
	}

	public static function nomod_for_woocommerce_block_support()
	{
		if (class_exists('Automattic\WooCommerce\Blocks\Payments\Integrations\AbstractPaymentMethodType')) {
			require_once 'includes/class-wc-nomod-blocks-support.php';
			add_action(
				'woocommerce_blocks_payment_method_type_registration',
				function ($payment_method_registry) {
					$payment_method_registry->register(new WC_Gateway_Nomod_Blocks_Support());
				}
			);
		}
	}

	public static function maybe_display_payment_failed_error()
	{
		// Display payment failed error message during checkout
		if (is_checkout()) {
			$payment_status = filter_input(INPUT_GET, 'payment_status', FILTER_SANITIZE_SPECIAL_CHARS);

			if ($payment_status && $payment_status === 'failed') {
				wc_add_notice(WC_Nomod_Messages::get_message('payment_failed'), 'error');
			}
		}
	}

	public static function nomod_for_woocommerce_hcoc_support()
	{
		// Check for compatibility with WooCommerce custom order tables
		if (class_exists(\Automattic\WooCommerce\Utilities\FeaturesUtil::class)) {
			\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility('custom_order_tables', __FILE__, true);
		}
	}

	public static function plugin_url()
	{
		return untrailingslashit(plugins_url('/', __FILE__));
	}

	public static function plugin_abspath()
	{
		return trailingslashit(plugin_dir_path(__FILE__));
	}
}

// Initialize the Nomod plugin
WC_Nomod::init();
