import { __ } from "@wordpress/i18n";
import { registerPaymentMethod } from "@woocommerce/blocks-registry";
import { decodeEntities } from "@wordpress/html-entities";
import { getSetting } from "@woocommerce/settings";

const settings = getSetting("nomod_data", {});
const defaultLabel = __("Nomod", "woo-gutenberg-products-block");
const label = decodeEntities(settings.title) || defaultLabel;

/**
 * Content component
 */
const Content = () => {
  return decodeEntities(settings.description || "");
};
/**
 * Label component
 *
 * @param {*} props Props from payment API.
 */
const Label = (props) => {
  const { PaymentMethodLabel } = props.components;
  return <PaymentMethodLabel text={label} />;
};

/**
 * Nomod payment method config object.
 */
const Nomod = {
  name: "nomod",
  label: <Label />,
  content: <Content />,
  edit: <Content />,
  canMakePayment: () => true,
  ariaLabel: label,
  supports: {
    features: settings.supports,
  },
};

registerPaymentMethod(Nomod);
